/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is CopySent2Current.
 *
 * The Initial Developer of the Original Code is Gnter Gersdorf.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Gnter Gersdorf <G.Gersdorf@ggbs.de>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
const DEBUG             = false; // set to false to suppress debug messages

const MY_CONTRACTID     = "@ggbs.de/copySent2Current;1";
const MY_NAME           = "Copy Sent to Current";
const MY_CID            = Components.ID("{980dc71c-962d-464c-af38-eb45984d2a13}");

//loadSubScript (in wstring url[, targetObj]);

function nsCopySent2Current() {
  this.URI         = null;
  this.label       = null;
  this.mLength     = 5;
  this.loaded      = null;

  this.prefB = Components.classes["@mozilla.org/preferences;1"].
      getService(Components.interfaces.nsIPref).getBranch("extensions.copysent2current.");

  this.promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
                    .getService(Components.interfaces.nsIPromptService);

//this.promptService.alert(null, 'info', 'load preferences');
  if (!this.loaded) { // not really necessary, only called once!
    try {
      this.mLength=this.prefB.getIntPref("lastusedlength");
    } catch(e) {this.mLength=5;}
    if (this.mLength>9) this.mLength=9;
    try {
      var uri=this.prefB.getCharPref("lastuseduri");
      if (uri && uri.charAt(0)=='[') this.URI=eval(uri);
      var label=this.prefB.getCharPref("lastusedlabel");
      if (label && label.charAt(0)=='[') this.label=eval(label);
    } catch(e) {
      this.label=new Array(0);
      this.URI=new Array(0);
    }
    this.loaded=true;
  }
}

nsCopySent2Current.prototype = {
  get length () {
//    if (!this.loaded) this._load();
    return this.URI.length;
  },
  get maxLength () {
//    if (!this.loaded) this._load();
    return this.mLength;
  },
  add: function(label, uri) {
//    if (!this.loaded) this._load();
    this.URI.unshift(uri);
    this.label.unshift(label);
    for (var i=1; i<this.URI.length; i++) {
      if (this.URI[i]==uri) {
        this.URI.splice(i, 1);
        this.label.splice(i, 1);
      }
    }
    if (this.URI.length>this.maxLength) {
      this.URI.pop();
      this.label.pop();
    }
    this.prefB.setCharPref("lastuseduri", this.URI.toSource());
    this.prefB.setCharPref("lastusedlabel", this.label.toSource());
  },
  get_URI: function(i) {
//    if (!this.loaded) this._load();
    if (i<this.URI.length)
      return this.URI[i];
    else
      return null;
  },
  get_label: function(i) {
//    if (!this.loaded) this._load();
    if (i<this.label.length)
      return this.label[i];
    else
      return null;
  },


/************* system functions **************************/
  observe: function(aSubject, aTopic, aData)
  {
//dump('cs2s-observer: '+aTopic+'\n');
    switch (aTopic)
    {
      case "nsPref:changed":
//dump('pref changed '+aSubject+' '+aData+'\n');
//aSubject ist ein nsIPrefBranch(2), aData ist die Preference
        if (aData=='checkLastModTime')  this.mCheckLastModTime  = null;
        break;
    }
  }
,

  QueryInterface: function (aIID)
  {
    if (!aIID.equals(Components.interfaces.CopySent2Current) &&
//        !aIID.equals(Components.interfaces.nsIObserver) &&
        !aIID.equals(Components.interfaces.nsISupports))
        throw Components.results.NS_ERROR_NO_INTERFACE;

    return this;
  }
}

var copySent2CurrentModule =
{
  registerSelf: function(aCompMgr, aFileSpec, aLocation, aType)
  {
    aCompMgr = aCompMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
    aCompMgr.registerFactoryLocation(MY_CID, MY_NAME, MY_CONTRACTID, aFileSpec, aLocation, aType);
  }
,
  unregisterSelf: function(aCompMgr, aFileSpec, aLocation)
  {
    aCompMgr = aCompMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
    aCompMgr.unregisterFactoryLocation(MY_CID, aFileSpec);
  }
,
  getClassObject: function (aCompMgr, aCID, aIID)
  {
    if (!aCID.equals(MY_CID))
      throw Components.results.NS_ERROR_NO_INTERFACE;

    if (!aIID.equals(Components.interfaces.nsIFactory))
      throw Components.results.NS_ERROR_NOT_IMPLEMENTED;

    return this.mFactory;
  }
,
  canUnload: function(aCompMgr)
  {
    return true;
  }
,
  /* factory object */
  mFactory:
  {
    createInstance: function(aOuter, aIID)
    {
      if (aOuter != null)
        throw Components.results.NS_ERROR_NO_AGGREGATION;

      return (new nsCopySent2Current()).QueryInterface(aIID);
    }
  ,
    lockFactory: function(aLock)
    {
      // quiten warnings
    }
  },
}

/* entrypoint */
function NSGetModule(aCompMgr, aFileSpec)
{
  return copySent2CurrentModule;
}

/* static functions */
if (DEBUG)
    debug = function (s) { dump("-*- CopySent2Current component: " + s + "\n"); }
else
    debug = function (s) {}
